package com.szyx.tcm.supervision.aop;

import com.fiftyonetrust.common.model.result.R;
import com.szyx.tcm.supervision.annotation.TraceLog;
import com.szyx.tcm.supervision.enums.LogLevelEnum;
import com.szyx.tcm.supervision.model.LogInfo;
import com.szyx.tcm.supervision.service.LogInfoService;
import lombok.extern.slf4j.Slf4j;
import org.aspectj.lang.JoinPoint;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Pointcut;
import org.aspectj.lang.reflect.MethodSignature;
import org.dromara.hutool.core.data.id.IdUtil;
import org.dromara.hutool.core.exception.ExceptionUtil;
import org.springframework.scheduling.annotation.EnableAsync;
import org.springframework.stereotype.Component;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.lang.reflect.Method;

/*******************************************************************
 * <pre></pre>
 * @文件名称： TraceLogAspect.java
 * @包 路  径： com.szyx.tcm.supervision.aop
 * @Copyright：wy (C) 2024 *
 * @Description:
 * @Version: V1.0
 * @Author： wy
 * @Date：2024/3/7 10:51
 * @Modify：
 */

@Component
@Aspect
@Slf4j
@EnableAsync
public class TraceLogAspect extends BaseAspect {


    @Resource
    private LogInfoService logInfoService;

    private long currentTime = 0L;

    @Pointcut("@annotation(com.szyx.tcm.supervision.annotation.TraceLog)")
    public void logPointcut() {
    }

    /**
     * 配置环绕通知,使用在方法logPointcut()上注册的切入点
     *
     * @param joinPoint join point for advice
     */
    @Around("logPointcut()")
    public Object logAround(ProceedingJoinPoint joinPoint) throws Throwable {
        currentTime = System.currentTimeMillis();
        Object result = joinPoint.proceed();
        LogInfo logBean = getResponseLogInfo(result);
        ServletRequestAttributes attributes = (ServletRequestAttributes) RequestContextHolder.getRequestAttributes();
        HttpServletRequest request = attributes.getRequest();
        if (result != null) {
            logBean.setPath(request.getRequestURI());
        }
        saveLog(joinPoint, logBean);
        return result;
    }


    private LogInfo getResponseLogInfo(Object result) {
        //判断返回结果
        LogInfo logBean = new LogInfo(LogLevelEnum.INFO.name(), System.currentTimeMillis() - currentTime);

        if (result instanceof R) {
            R res = (R) result;
            if (res.getCode() == 200) {
                logBean.setLogType(LogLevelEnum.INFO.name());

            } else {
                logBean.setLogType(LogLevelEnum.ERROR.name());
                logBean.setExceptionDetail(res.getMessage());
            }
        }
        logBean.setRequestId(IdUtil.nanoId(20));
        return logBean;
    }

    private void saveLog(JoinPoint joinPoint, LogInfo logBean) {

        try {
            MethodSignature signature = (MethodSignature) joinPoint.getSignature();
            Method method = signature.getMethod();
            TraceLog traceable = method.getAnnotation(TraceLog.class);
            String methodName = method.getName();
            //注解入参
            logBean.setDescription(traceable.desc());
            //方法全路径
            logBean.setMethodName(joinPoint.getTarget().getClass().getName() + "." + methodName + "()");
            logInfoService.save(logBean);


        } catch (Exception e) {
            log.error("日志AOP封装log对象异常: {}", ExceptionUtil.stacktraceToString(e));
        }

    }


}
