package com.szyx.tcm.supervision.controller;

import com.fiftyonetrust.common.model.result.R;
import com.fiftyonetrust.common.util.YAssert;
import com.github.benmanes.caffeine.cache.Caffeine;
import com.github.benmanes.caffeine.cache.LoadingCache;
import com.szyx.tcm.supervision.annotation.TraceLog;
import com.szyx.tcm.supervision.config.CacheAgent;
import com.szyx.tcm.supervision.constant.CacheConstant;
import com.szyx.tcm.supervision.enums.OperationTypeEnum;
import com.szyx.tcm.supervision.model.LogInfo;
import com.szyx.tcm.supervision.model.dto.supervise.SuperviseTokenRep;
import com.szyx.tcm.supervision.service.IBaseBusinessService;
import com.szyx.tcm.supervision.service.insurance.InsuranceUploadDetailBusinessService;
import lombok.extern.slf4j.Slf4j;
import org.dromara.hutool.core.date.DateUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.time.Instant;
import java.util.Date;
import java.util.List;
import java.util.concurrent.TimeUnit;

/*******************************************************************
 * <pre></pre>
 * @文件名称： TestController.java
 * @包 路  径： com.szyx.tcm.supervision.controller
 * @Copyright：wy (C) 2024 *
 * @Description:
 * @Version: V1.0
 * @Author： wy
 * @Date：2024/3/7 13:28
 * @Modify：
 */
@RestController
@RequestMapping("/test")
@Slf4j
public class TestController {


    @Resource
    private CacheAgent cacheAgent;

    @Autowired
    List<InsuranceUploadDetailBusinessService> baseBusinessServiceList;


    @GetMapping("/get")
    @TraceLog(desc = "测试接口")
    public R<String> get(){

        System.out.println("baseBusinessServiceList = " + baseBusinessServiceList);


        return R.ok("success");
    }

    /**
     * 生成token header
     *
     * @return
     */
    private String generateToken() {
        LoadingCache<String, SuperviseTokenRep> cache = Caffeine.newBuilder()
                .expireAfterWrite(120, TimeUnit.SECONDS)
                .build(key -> this.getToken());

        SuperviseTokenRep rep = cache.get(CacheConstant.SUPERVISE_TOKEN);
        String token = null;
        if (rep != null) {
            token = rep.getAccess_token();
            log.info("更新监管平台token成功,token:{},过期时间为:{}", rep.getAccess_token(), DateUtil.offsetSecond(new Date(), rep.getExpires_in()));
        } else {
            log.warn("更新监管平台token失败");
        }
        return token;
    }

    @PostMapping("/post")
    @TraceLog(desc = "测试接口",operationType = OperationTypeEnum.POST)
    public R<String> post(@RequestBody LogInfo body){


        SuperviseTokenRep rep = cacheAgent.get(CacheConstant.SUPERVISE_TOKEN);

        if(null == rep){
            rep = getToken();
            cacheAgent.put(CacheConstant.SUPERVISE_TOKEN,rep);
        }





//        YAssert.notNull(null,"监管平台token获取失败");

        return R.ok("success");
    }



    public SuperviseTokenRep getToken(){
        return SuperviseTokenRep.builder().access_token(Instant.now().toString()).expires_in(1).build();
    }



}
