package com.szyx.tcm.supervision.exception;

/**
 * @program: tcm-parent
 * @ClassName HttpException
 * @description:
 * @author: jwmd
 * @create: 2023-04-24 20:36
 **/
public class HttpException extends RuntimeException {
    private final int httpStatusCode;

    private String errorMsg;

    public HttpException(int httpStatusCode, String errorMsg) {
        this.httpStatusCode = httpStatusCode;
        this.errorMsg = errorMsg;

    }

    /**
     * Maps an Exception based on the underlying status code
     *
     * @param httpStatusCode the Http Status Code
     * @return the response exception
     */
    public static HttpException mapException(int httpStatusCode, String errorMsg) {
        return new HttpException(httpStatusCode, errorMsg);
    }

    /**
     * @return return the raw status code
     */
    public int getHttpStatusCode() {
        return httpStatusCode;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    @Override
    public String toString() {
        StringBuilder sb;
        sb = new StringBuilder();
        sb.append(this.getClass().getSimpleName()).append(" {\n");
        sb.append("    httpStatusCode: ").append(toIndentedString(httpStatusCode)).append("\n");
        sb.append("    errorMsg: ").append(toIndentedString(errorMsg)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces
     * (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}