package com.szyx.tcm.supervision.model.dto.insurance;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.annotation.JSONField;
import lombok.Data;

import java.math.BigDecimal;
import java.util.List;

/*******************************************************************
 * <pre></pre>
 * @文件名称： InsuranceCoreOutputMessage1101.java
 * @包 路  径： com.szyx.tcm.web.patient.dto.insurance
 * @Copyright：wy (C) 2024 *
 * @Description:
 * @Version: V1.0
 * @Author： wy
 * @Date： 2024/7/22 14:23
 * @Modify：
 */
@Data
public class InsuranceCoreOutputMessage1101 {

    /**
     * 输出-基本信息
     */
    private Baseinfo baseinfo;

    /**
     * 输出-参保信息列表
     */
    private Insuinfo insuinfo;

    /**
     * 输出-身份信息列表
     */
    private List<Idetinfo> idetinfo;


    @Data
    public static class Baseinfo{
        /**
         * psn_no	人员编号	字符型	30		Y
         */
        @JSONField(name = "psn_no")
        private String psnNo;

        /**
         * psn_cert_type	人员证件类型	字符型	6	Y	Y
         */
        @JSONField(name = "psn_cert_type")
        private String psnCertType;

        /**
         * certno	证件号码	字符型	50		Y
         */
        private String certno;

        /**
         * psn_name	人员姓名	字符型	50		Y
         */
        @JSONField(name = "psn_name")
        private String psnName;

        /**
         * gend	性别	字符型	6	Y	Y
         */
        private String gend;

        /**
         * naty	民族	字符型	3	Y
         */
        private String naty;

        /**
         * brdy	出生日期	日期型				yyyy-MM-dd
         */
        private String brdy;

        /**
         * age	年龄	数值型	4,1		Y
         */
        private String age;

        /**
         * exp_content	字段扩展	字符型	4000			只有居民返回
         * 家庭账户余额
         * 门诊统筹累计
         * {
         * “fm_acct_amt”:0
         * “jmmztc_cum”:0
         * }
         */
        private ExpContent expContent;

        @Data
        public class ExpContent {

            /**
             * fm_acct_amt	家庭账户余额	数值型	16,2			只有居民返回
             */
            private String fmAcctAmt;

            /**
             * jmmztc_cum	门诊统筹累计	数值型	16,2			只有居民返回
             */
            private String jmmztcCum;

            /**
             * mat_idet_flag	医疗救助标识	字符型	6			0否，1是
             */
            private String matIdetFlag;

            /**
             * mat_idet_code	救助对象身份	字符型	10	Y
             */
            private String matIdetCode;


        }





    }

    @Data
    public static class Insuinfo{

        /**
         * psn_insu_rlts_id	人员参保关系ID	字符型	20
         */
        @JSONField(name = "psn_insu_rlts_id")
        private String psnInsuRltsId;

        /**
         * balc	余额	数值型	16,2		Y
         */
        private BigDecimal balc;

        /**
         * insutype	险种类型	字符型	6	Y	Y
         */
        private String insutype;

        /**
         * psn_type	人员类别	字符型	6	Y	Y
         */
        @JSONField(name = "psn_type")
        private String psnType;

        /**
         * psn_insu_stas	人员参保状态	字符型	6	Y
         */
        @JSONField(name = "psn_insu_stas")
        private String psnInsuStas;

        /**
         * psn_insu_date	个人参保日期	日期型
         */
        private String psnInsuDate;

        /**
         * paus_insu_date	暂停参保日期	日期型
         */
        private String pausInsuDate;

        /**
         * cvlserv_flag	公务员标志	字符型	3	Y	Y
         */
        @JSONField(name = "cvlserv_flag")
        private String cvlservFlag;

        /**
         * insuplc_admdvs	参保地医保区划	字符型	6		Y
         */
        private String insuplcAdmdvs;

        /**
         * emp_name	单位名称	字符型	200
         */
        @JSONField(name = "emp_name")
        private String empName;

    }

    @Data
    public class Idetinfo{

        /**
         * psn_idet_type	人员身份类别	字符型	10	Y	Y
         */
        @JSONField(name = "psn_idet_type")
        private String psnIdetType;

        /**
         * psn_type_lv	人员类别等级	字符型	3	Y		详见残疾等级字典
         */
        @JSONField(name = "psn_type_lv")
        private String psnTypeLv;

        /**
         * memo	备注	字符型	500
         */
        private String memo;

        /**
         * begntime	开始时间	日期时间型			Y
         */
        private String begntime;

        /**
         * endtime	结束时间	日期时间型
         */
        private String endtime;

    }


    public static void main(String[] args) {

        String s = "{\n" +
                "  \"infcode\": \"1\",\n" +
                "  \"inf_refmsgid\": \"000000202001041235391234567890\",\n" +
                "  \"refmsg_time\": \"20200201133411352\",\n" +
                "  \"respond_time\": \"20200202133731456\",\n" +
                "  \"err_msg\": \"\",\n" +
                "  \"output\": {\n" +
                "    \"baseinfo\": {\n" +
                "      \"psn_no\": \"131000202001001\",\n" +
                "      \"psn_cert_type\": \"2\",\n" +
                "      \"certno\": \"510000202001010000\",\n" +
                "      \"psn_name\": \"李四\",\n" +
                "      \"gend\": \"1\",\n" +
                "      \"naty\": \"01\",\n" +
                "      \"brdy\": \"2020-01-01\",\n" +
                "      \"age\": 18\n" +
                "    },\n" +
                "    \"insuinfo\": {\n" +
                "      \"psn_insu_rlts_id\": \"133241523001001\",\n" +
                "      \"balc\": 5000,\n" +
                "      \"insutype\": \"310\",\n" +
                "      \"psn_type\": \"1001\",\n" +
                "      \"cvlserv_flag\": \"0\",\n" +
                "      \"insu_admdvs\": \"131002\",\n" +
                "      \"emp_name\": \"测试单位\"\n" +
                "    },\n" +
                "    \"idetinfo\": [\n" +
                "      {\n" +
                "        \"psn_idet_type\": \"1\",\n" +
                "        \"psn_type_lv\": \"1\",\n" +
                "        \"memo\": \"\",\n" +
                "        \"begntime\": \"2020-01-01 00:00:00\",\n" +
                "        \"endtime\": \"\"\n" +
                "      },\n" +
                "      {\n" +
                "        \"psn_idet_type\": \"2\",\n" +
                "        \"psn_type_lv\": \"1\",\n" +
                "        \"memo\": \"\",\n" +
                "        \"begntime\": \"2020-01-01 00:00:00\",\n" +
                "        \"endtime\": \"\"\n" +
                "      }\n" +
                "    ]\n" +
                "  }\n" +
                "}";




        InsuranceCoreCommonOutputMessage outputMessage = JSON.parseObject(s, InsuranceCoreCommonOutputMessage.class);

        // 收到的1101报文
        InsuranceCoreOutputMessage1101 insuranceCoreOutputMessage1101 = JSON.parseObject(outputMessage.getOutput(), InsuranceCoreOutputMessage1101.class);

        System.out.println(insuranceCoreOutputMessage1101);

    }









}
