package com.szyx.tcm.supervision.model.dto.insurance;

import io.swagger.annotations.ApiModel;
import lombok.Data;

import java.math.BigDecimal;
import java.util.List;

/*******************************************************************
 * <pre></pre>
 * @文件名称： InsuranceUploadRecipeDetailDTO.java
 * @包 路  径： com.szyx.tcm.web.patient.dto.insurance
 * @Copyright：wy (C) 2024 *
 * @Description:
 * @Version: V1.0
 * @Author： wy
 * @Date： 2024/7/17 14:36
 * @Modify：
 */
@Data
@ApiModel("省医保平台「6201」上传处方药费明细请求参数")
public class InsuranceUploadRecipeDetailInputMessage {

        /**
         * orgCodg	机构编码	字符型	40		Y	医保分配
         */
        private String orgCodg;

        /**
         * orgId	电子凭证机构号	字符型	40		N	电子凭证中台分配，待机构电子凭证建设完毕后可获取该机构号
         */
        private String orgId;

        /**
         * psnNo	人员编号	字符型	30		Y
         */
        private String psnNo;

        /**
         * insutype	险种类型	字符型	6		Y	字典险种类型
         * (insutype)
         */
        private String insutype;

        /**
         * medOrgOrd	医疗机构订单号	字符型	40		Y	院内产生惟一流水，可关联到一次结算记录，结算成功回调入参返回
         */
        private String medOrgOrd;

        /**
         * rxCircFlag	电子处方流转标志	字符型	1		N	1：电子处方 ，0不是电子处方，默认0，非电子处方
         */
        private String rxCircFlag = "0";

        /**
         * begntime	开始时间	字符型	19		Y	挂号时间
         * yyyy-MM-dd HH:mm:ss
         */
        private String begntime;

        /**
         * idNo	证件号码	字符型	40		Y
         */
        private String idNo;

        /**
         *userName	用户姓名	字符型	40		Y
         */
        private String userName;

        /**
         * idType	证件类别	字符型	3		Y	字典人员证件类型(psn_cert_type) 01：身份证
         */
        private String idType;

        /**
         * ecToken	电子凭证授权ecToken	字符型	64		Y	电子凭证解码返回
         */
        private String ecToken;

        /**
         * insuCode	就诊参保地行政区划	字符型	6		N	为空(null)时取用户电子凭证默认参保地
         */
        private String insuCode;

        /**
         * iptOtpNo	住院/门诊号	字符型	30		Y	院内唯一流水
         */
        private String iptOtpNo;

        // ==================非必需字段===================

        /**
         * atddrNo	医师编码	字符型	30		N
         */
        private String atddrNo;

        /**
         *drName	医师姓名	字符型	50		N
         */
        private String drName;

        /**
         * deptCode	科室编码	字符型	30		N
         */
        private String deptCode;


        // =====================================

        /**
         *deptName	科室名称	字符型	100		Y
         */
        private String deptName;

        /**
         * caty	科别	字符型	6		Y
         */
        private String caty;

        /**
         * mdtrtId	就诊ID	字符型	30		N
         */
        private String mdtrtId;

        /**
         *medType	医疗类别	字符型	6		Y	字典医疗类别
         * (med_type)  91 其他门诊
         */
        private String medType;

        /**
         * feeType	费用类型	字符型	3		Y	字典费用类型（feeType） 05 互联网医院问诊
         */
        private String feeType;

        /**
         * medfeeSumamt	医疗费总额	数值型	16,2		Y
         */
        private BigDecimal medfeeSumamt;

        //  todo 貌似目前为海南医保的特有字段
        /**
         * acctUsedFlag	个人账户使用标志	字符型	1		Y	药店上传费用时必填
         */
        private String  acctUsedFlag;

        /**
         * mainCondDscr	主要病情描述	字符型	1000		N
         */
        private String mainCondDscr;

        /**
         *diseCodg	病种编码	字符型	30		Y	按照标准编码填写：
         * 按病种结算病种目录代码(bydise_setl_list_code)、
         * 门诊慢特病病种目录代码(opsp_dise_cod)、
         */
        private String diseCodg;

        /**
         * diseName	病种名称	字符型	500		Y
         */
        private String diseName;

        // todo 貌似目前为海南医保的特有字段
        /**
         * psnSetlway	个人结算方式	字符型	6		Y
         */
        private String  psnSetlway;

        /**
         * chrgBchno	收费批次号	字符型	30		Y
         */
        private  String chrgBchno;

        /**
         * pubHospRfomFlag	公立医院改革标志	字符型	6		Y	可参考FSI的接口要求
         */
        private String  pubHospRfomFlag;

        /**
         * diseinfoList	诊断或症状明细				Y	见下方diseinfoList定义
         */
        private List<DiseInfo> diseinfoList;

        /**
         * feedetailList	费用明细				Y	见下方feedetailList定义
         */
        private List<FeeDetail> feedetailList;

        /**
         * payAuthNo	支付授权码	字符型	40		N	线上授权返回
         */
        private String payAuthNo;


        public static void main(String[] args) {

                String s = "{\n" +
                        "\t\"configId\": \"cs1\",（部分省份无该参数，可去除）\n" +
                        "\t\"payAuthNo\": \"AUTH430100202206132005090000100\",\n" +
                        "\t\"uldLatlnt\": \"112.88211,28.230932\",\n" +
                        "\t\"idType\": \"01\",\n" +
                        "\t\"mdtrtCertType\": \"02\",\n" +
                        "\t\"orgCodg\": \"H43010000001\",\n" +
                        "\t\"orgId\": \"\",\n" +
                        "\t\"psnNo\": \"430000201000000000\",\n" +
                        "\t\"insutype\": \"310\",\n" +
                        "\t\"medOrgOrd\": \"46515950\",\n" +
                        "\t\"begntime\": \"2022-06-13 17:57:07\",\n" +
                        "\t\"idNo\": \"430602199111111111\",\n" +
                        "\t\"userName\": \"刘军\",\n" +
                        "\t\"ecToken\": \"\",\n" +
                        "\t\"iptOtpNo\": \"4441829\",\n" +
                        "\t\"deptCode\": \"2101\",\n" +
                        "\t\"deptName\": \"心血管内科诊室（一）\",\n" +
                        "\t\"caty\": \"2101\",\n" +
                        "\t\"mdtrtId\": \"359999999\",\n" +
                        "\t\"medType\": \"11\",\n" +
                        "\t\"feeType\": \"01\",\n" +
                        "\t\"medfeeSumamt\": 53.69,\n" +
                        "\t\"acctUsedFlag\": \"\",\n" +
                        "\t\"diseCodg\": \"J00.x00x002\",\n" +
                        "\t\"diseName\": \"病毒性感冒\",\n" +
                        "\t\"psnSetlway\": \"01\",\n" +
                        "\t\"chrgBchno\": \"4441829694.42\",\n" +
                        "\t\"pubHospRfomFlag\": \"01\",\n" +
                        "\t\"fetts\": \"\",\n" +
                        "\t\"diseinfoList\": [{\n" +
                        "\t\t\"diagType\": \"0\",\n" +
                        "\t\t\"diagSrtNo\": 1,\n" +
                        "\t\t\"diagCode\": \"J00.x00x002\",\n" +
                        "\t\t\"diagName\": \"病毒性感冒\",\n" +
                        "\t\t\"diagDept\": \"心血管内科诊室（一）\",\n" +
                        "\t\t\"diseDorNo\": \"0824\",\n" +
                        "\t\t\"diseDorName\": \"马丽霞\",\n" +
                        "\t\t\"diagTime\": \"2022-06-13 17:57:23\",\n" +
                        "\t\t\"valiFlag\": \"1\"\n" +
                        "\t}],\n" +
                        "\t\"feedetailList\": [{\n" +
                        "\t\t\t\"feedetlSn\": \"97657430\",\n" +
                        "\t\t\t\"mdtrtId\": \"4441888\",\n" +
                        "\t\t\t\"psnNo\": \"430000201000000000\",\n" +
                        "\t\t\t\"chrgBchno\": \"444182920220613175815266\",\n" +
                        "\t\t\t\"rxCircFlag\": \"0\",\n" +
                        "\t\t\t\"feeOcurTime\": \"2022-06-13 17:57:08\",\n" +
                        "\t\t\t\"medListCodg\": \"F00000019080\",\n" +
                        "\t\t\t\"medinsListCodg\": \"H43010500027\",\n" +
                        "\t\t\t\"detItemFeeSumamt\": 16,\n" +
                        "\t\t\t\"cnt\": 1,\n" +
                        "\t\t\t\"pric\": 16,\n" +
                        "\t\t\t\"bilgDeptCodg\": \"2101\",\n" +
                        "\t\t\t\"bilgDeptName\": \"心血管内科诊室（一）\",\n" +
                        "\t\t\t\"bilgDrCodg\": \"0824\",\n" +
                        "\t\t\t\"bilgDrName\": \"马丽霞\",\n" +
                        "\t\t\t\"hospApprFlag\": \"1\",\n" +
                        "\t\t\t\"medType\": \"11\",\n" +
                        "\t\t\t\"medListName\": \"副主任医师普通门诊诊查费\",\n" +
                        "\t\t\t\"medListSpc\": \"\"\n" +
                        "\t\t},\n" +
                        "\t\t{\n" +
                        "\t\t\t\"feedetlSn\": \"97657431\",\n" +
                        "\t\t\t\"mdtrtId\": \"4441888\",\n" +
                        "\t\t\t\"psnNo\": \"430000201000000000\",\n" +
                        "\t\t\t\"chrgBchno\": \"444182920220613175815266\",\n" +
                        "\t\t\t\"rxCircFlag\": \"0\",\n" +
                        "\t\t\t\"feeOcurTime\": \"2022-06-13 17:57:36\",\n" +
                        "\t\t\t\"medListCodg\": \"Y00000020302\",\n" +
                        "\t\t\t\"medinsListCodg\": \"H43010500027\",\n" +
                        "\t\t\t\"detItemFeeSumamt\": 678.42,\n" +
                        "\t\t\t\"cnt\": 18,\n" +
                        "\t\t\t\"pric\": 37.69,\n" +
                        "\t\t\t\"bilgDeptCodg\": \"2101\",\n" +
                        "\t\t\t\"bilgDeptName\": \"心血管内科诊室（一）\",\n" +
                        "\t\t\t\"bilgDrCodg\": \"0824\",\n" +
                        "\t\t\t\"bilgDrName\": \"马丽霞\",\n" +
                        "\t\t\t\"hospApprFlag\": \"1\",\n" +
                        "\t\t\t\"medType\": \"11\",\n" +
                        "\t\t\t\"medListName\": \"小儿肺咳颗粒\",\n" +
                        "\t\t\t\"medListSpc\": \"2g/袋*18袋/盒\"\n" +
                        "\t\t}\n" +
                        "\t]\n" +
                        "}\n";









        }



}
