package com.szyx.tcm.supervision.model.dto.insurance;

import lombok.Data;

/*******************************************************************
 * <pre></pre>
 * @文件名称： WechatUnifiedOrderReq.java
 * @包 路  径： com.szyx.tcm.web.patient.dto.insurance
 * @Copyright：wy (C) 2024 *
 * @Description: 微信统一下单请求参数
 * @Version: V1.0
 * @Author： wy
 * @Date： 2024/7/23 23:23
 * @Modify：
 */
@Data
public class WechatUnifiedOrderReq {

    /**
     * order_type
     * 支付类型
     * String16
     * Y
     * RegPay=挂号支付
     * MedPay=药费支付
     * DiagPay=诊间支付
     * InHospPay=住院费支付
     * PharmacyPay=药店支付
     * InsurancePay=保险费支付
     * IntRegPay=互联网医院挂号支付
     * IntReDiagPay=互联网医院复诊支付
     * IntPscPay=互联网医院处方支付
     * CovidExamPay=新冠检测费用
     * CvidAntigenPay=新冠抗原检测
     */
    private String orderType;

    /**
     * appid
     * 公众账号ID
     * String32
     * Y
     * 微信分配的公众账号ID
     */
    private String appid;

    /**
     * mch_id
     * 商户号
     * String32
     * Y
     * 微信支付分配的商户号
     */
    private String mchId;

    /**
     * sub_appid
     * 子商户公众号ID
     * String32
     * N
     * 微信分配的子商户公众账号ID，如需在支付完成后获取sub_openid则此参数必传。
     */
    private String subAppid;

    /**
     * sub_mch_id
     * 子商户号
     * String32
     * N
     * 微信支付分配的子商户号,如果是服务商模式,必填
     */
    private String subMchId;

    /**
     * openid
     * 用户标识
     * String128
     * 二选一
     * openid和sub_openid可以选传其中之一，如果选择传sub_openid,则必须传sub_appid。
     */
    private String openid;



    /**
     * hosp_out_trade_no
     * 第三方服务商订单号
     * String64
     * Y
     * 第三方服务商平台自动生成的一个订单号
     */
    private String hospOutTradeNo;

    /**
     * hospital_name
     * 医院名称
     * string128
     * Y
     * 医院名称
     */
    private String hospitalName;

    /**
     * nonce_str
     * 随机字符串
     * String32
     * Y
     */
    private String nonceStr;

    /**
     * total_fee
     * 总共需要支付现金金额
     * Uint64
     * Y
     * 单位为分>0
     * 表示订单总额即全额现金的价格。由于医保局支付有优惠，全额现金的价格可能会大于cash_fee+ insurance_fee的和，不一定等于cash_fee+insurance_fee。
     */
    private String totalFee;

    /**
     * cash_fee
     * 现金需要支付的金额
     * Uint64
     * Y
     * 单位为分>=0
     * 线上预结算模式金额填0
     * 线下预结算模式填实际自费金额
     */
    private String cashFee;

    /**
     * cash_add_fee
     * 由医疗机构额外增加的现金金额
     * Uint64
     * N
     * 单位为分，默认0
     * 用于医院在医保预结算之外增加现
     * 金扣费，举例:原需要
     * 支付的是:
     * total_ fee 200
     * cash_ fee 100
     * insurance fee 100。
     * 现新增现金50，则入参为:
     * total_ _fee 250 ( 总额加上额外现
     * 金)
     * cash fee 150(自费加上额外现
     * 金)
     * cash_add_ fee 50 (额外现金)
     * insurance_ fee 100
     */

    private String cashAddFee;

    /**
     * cash_add_wording
     * 额外现金金额文案
     * String16
     * N
     * 额外现金金额，如:快递费
     * 目前不会在前端显示，可不传
     */
    private String cashAddWording;

    /**
     * cash_reduced_wording
     * 减免金额文案
     * String16
     * N
     * 减免金额的文案类型，
     * 1为：预交金支付
     * 2为：医院减免
     * 3为：药店优惠
     * 4为：优惠金
     * 5为：押金抵扣
     * 不填则为默认的“机构优惠金额”
     */
    private String cashReducedWording;

    /**
     * allow_fee_change
     * 是否允许预结算费用发生变化
     * uint8
     * Y
     * 0：不允许
     * 1：允许
     * 当医保局返回的预结算金额与医院上传的金额不一致时，此字段为0则直接报错，为1则以医保局金额为准
     */
    private String allowFeeChange;

    /**
     * spbill_create_ip
     * 用户端ip
     * String16
     * Y
     * 10.193.0.1
     */
    private String spbillCreateIp;

    /**
     * notify_url
     * 回调url
     * String256
     * Y
     * 接收微信支付异步通知回调地址
     */
    private String notifyUrl;

    /**
     * body
     * 商品描述
     * String128
     * Y
     * 参照
     * https://pay.weixin.qq.com/wiki/doc/api/jsapi.php?chapter=4_2
     */
    private String body;

    /**
     * return_url
     * 支付后回跳的页面，不论成功或者失败均会回跳
     * string128
     * Y
     * 调用方可以在链接中加上支付单号，回跳后查询调用方订单状态，如果订单已支付则成功， 如果订单未支付则进行查单操作确认订单结果
     */
    private String returnUrl;

    /**
     * pay_type
     * 支付方式
     * uint8
     * Y
     * 1：现金 2：医保 3：现金+医保
     * 备注说明：
     * 1、当订单要走医保支付时，
     * （1）cash_fee>0, paytype填3
     * （2）cash_fee=0, paytype填2
     * 2、当订单不使用医保支付时 paytype填1。
     * 3、当订单有走医保【6201】相关接口时，如果订单为纯自费订单，paytype填3。
     */
    private String payType;

    /**
     * city_id
     * 城市ID
     * String32
     * Y
     * 一般为申请接入城市的编码，由腾讯侧对接时提供。
     */
    private String cityId;


    /**
     * consume_type
     * 医保部分扣
     * 费类型
     * int8
     * N
     * 默认为 0：统筹+个账
     * 1：个账
     * 2：统筹
     */
    private String consumeType;

    /**
     * insurance_fee
     * 医保支付金额
     * Uint64
     * Y
     * 填实际医保金额
     */
    private String insuranceFee;

    /**
     * 证件类型 user_card_type 1 居民身份证 9 户口本 8 外国人护照 5 台湾居民来往大陆通行证 4 澳门居民往来内地通行证 6 香港居民往来内地通行证 7 外国人永久居留证
     */
    private String userCardType;

    /**
     * 证件号码 user_card_no 证件号码的MD5，目前只支持身份证（身份证中如果有字母需要转成大写再做MD5,15位身份证号需要转为18位）. 示例：44030019000101123x的MD5为09eb26e839ff3a2e3980352ae45ef09e
     */
    private String userCardNo;

    /**
     * 真实姓名 user_name 张三
     */
    private String userName;

    /**
     * 医保标识 is_dept is_dept=4 医保电子凭证支付；
     */
    private String isDept;

    /**
     * 医院HIS系统订单号 serial_no 医院HIS系统订单号
     */
    private String serialNo;

    /**
     * 医疗机构编码（医保局分配给机构） org_no 医保局局提供的医疗机构编码
     */
    private String orgNo;

    /**
     * 医院下单时间 gmt_out_create 格式为yyyyMMddHHmmss 如20160501163102
     */
    private String gmtOutCreate;

    /**
     * 参考医保结构体（医疗机构透传医保） request_content 示例: {"payAuthNo":"AUTH****","payOrdId":"ORD****","setlLatlnt":"118.096435,24.485407"} payAuthNo：授权码 payOrdId：对应处方上传的出参单号 setlLatlnt：用户地 理定位信息, 经纬 度信息，如“118.096435,24.485407”。未获取到用户定位时，传“0,0”。
     */
    private String requestContent;

    /**
     * 业务单据号 bill_no
     */
    private String billNo;

    /**
     * 签名 sign
     */
    private String sign;


}
