package com.szyx.tcm.supervision.model.dto.supervise;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.dataformat.xml.annotation.JacksonXmlProperty;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.util.Date;

/**
 * @program: tcm-parent
 * @ClassName MedicalAdvice
 * @description: 医嘱明细
 * @author: jwmd
 * @create: 2023-05-19 19:06
 **/
@Data
public class MedicalAdvice {

    @ApiModelProperty(value = "医嘱类型编码", required = true)
    @JacksonXmlProperty(localName = "E01")
    private Integer medicalAdviceTypeCode;
    /**
     * 处方类医嘱必填此项
     */
    @ApiModelProperty(value = "处方号")
    @JacksonXmlProperty(localName = "E02")
    private String prescriptionNo;

    @ApiModelProperty(value = "医嘱项目编码", required = true)
    @JacksonXmlProperty(localName = "E03C")
    private String medicalAdviceCode;

    @ApiModelProperty(value = "医嘱项目名称", required = true)
    @JacksonXmlProperty(localName = "E03N")
    private String medicalAdviceName;

    /**
     * YYYY-MM-DD HH24:MI:SS
     */
    @ApiModelProperty(value = "医嘱时间")
    @JacksonXmlProperty(localName = "E04")
    @JsonFormat( pattern= "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date medicalAdviceTime;

    /**
     * 常规药品，规格必填；药品规格应包括药品最小计算单位的含量及每个包装所含药品的数量。例如：0.1g*6片
     */
    @ApiModelProperty(value = "规格")
    @JacksonXmlProperty(localName = "E05")
    private String specs;

    @ApiModelProperty(value = "给药途径")
    @JacksonXmlProperty(localName = "E06C")
    private String routeofDose;

    @ApiModelProperty(value = "数量")
    @JacksonXmlProperty(localName = "E07")
    private Double number;

    @ApiModelProperty(value = "单价")
    @JacksonXmlProperty(localName = "E08")
    private Double unitPrice;

    @ApiModelProperty(value = "每次用量")
    @JacksonXmlProperty(localName = "E09")
    private Double eachUsage;

    @ApiModelProperty(value = "每次用量单位")
    @JacksonXmlProperty(localName = "E10C")
    private String eachUsageUnit;

    @ApiModelProperty(value = "频度")
    @JacksonXmlProperty(localName = "E11C")
    private String frequentness;

    @ApiModelProperty(value = "执行天数")
    @JacksonXmlProperty(localName = "E12")
    private Integer executionDays;

    @ApiModelProperty(value = "收费标志")
    @JacksonXmlProperty(localName = "E13C")
    private Integer chargeSign;
}