package com.szyx.tcm.supervision.model.dto.supervise;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.dataformat.xml.annotation.JacksonXmlElementWrapper;
import com.fasterxml.jackson.dataformat.xml.annotation.JacksonXmlProperty;
import com.fasterxml.jackson.dataformat.xml.annotation.JacksonXmlRootElement;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.util.Date;
import java.util.List;

/**
 * @program: tcm-parent
 * @ClassName SuperviseDto
 * @description: 监管平台数据实体类
 * @author: jwmd
 * @create: 2023-05-22 14:53
 **/
@Data
@JacksonXmlRootElement(localName = "CASE")
public class SuperviseDto {
    /**
     * 组织机构代码长度为9位字符
     */
    @ApiModelProperty(value = "就诊医院编码", required = true)
    @JacksonXmlProperty(localName = "A01C")
    private String hospitalNo;
    @ApiModelProperty(value = "就诊医院名称", required = true)
    @JacksonXmlProperty(localName = "A01N")
    private String hospitalName;
    /**
     * 与医疗保险相关的分类
     */
    @ApiModelProperty(value = "患者编码类型", required = true)
    @JacksonXmlProperty(localName = "B01C")
    private String patientNoType;
    /**
     * 医保患者必须填写医保卡号
     */
    @ApiModelProperty(value = "患者编码", required = true)
    @JacksonXmlProperty(localName = "B02")
    private String patientNo;
    @ApiModelProperty(value = "姓名", required = true)
    @JacksonXmlProperty(localName = "B03C")
    private String name;
    @ApiModelProperty(value = "性别", required = true)
    @JacksonXmlProperty(localName = "B04C")
    private Integer gender;
    @ApiModelProperty(value = "出生日期 YYYY-MM-DD", required = true)
    @JacksonXmlProperty(localName = "B05C")
    @JsonFormat( pattern= "yyyy-MM-dd", timezone = "GMT+8")
    private Date birthday;
    @ApiModelProperty(value = "证件类型", required = true)
    @JacksonXmlProperty(localName = "B06C")
    private Integer idType;
    /**
     * 身份证长度应为18位（或15位）
     */
    @ApiModelProperty(value = "证件号码", required = true)
    @JacksonXmlProperty(localName = "B07C")
    private String idNumber;
    @ApiModelProperty(value = "民族")
    @JacksonXmlProperty(localName = "B08C")
    private Integer nation;
    @ApiModelProperty(value = "国籍", required = true)
    @JacksonXmlProperty(localName = "B09C")
    private Integer country;
    @ApiModelProperty(value = "婚姻状况")
    @JacksonXmlProperty(localName = "B10C")
    private Integer maritalState;
    @ApiModelProperty(value = "工作单位")
    @JacksonXmlProperty(localName = "B11")
    private String company;
    @ApiModelProperty(value = "现居住详细地址（居住半年以上）")
    @JacksonXmlProperty(localName = "B12")
    private String liveAddress;
    @ApiModelProperty(value = "现住址行政区划编码（居住半年以上）", required = true)
    @JacksonXmlProperty(localName = "B13C")
    private String areaCode;
    @ApiModelProperty(value = "联系人姓名")
    @JacksonXmlProperty(localName = "B14")
    private String contactName;
    @ApiModelProperty(value = "联系人电话")
    @JacksonXmlProperty(localName = "B15")
    private String contactPhone;
    @ApiModelProperty(value = "联系人身份证号")
    @JacksonXmlProperty(localName = "B16")
    private String contactIdCard;
    /**
     * 患者≤6岁时必填此项
     */
    @ApiModelProperty(value = "监护人姓名")
    @JacksonXmlProperty(localName = "B17")
    private String guardianName;
    /**
     * 患者≤6岁时必填此项
     */
    @ApiModelProperty(value = "监护人联系方式")
    @JacksonXmlProperty(localName = "B18")
    private String guardianPhone;
    /**
     * 医院提供，一次就诊的唯一标识，就诊流水号
     */
    @ApiModelProperty(value = "就诊流水号", required = true)
    @JacksonXmlProperty(localName = "C01")
    private String visitSerialNumber;
    @ApiModelProperty(value = "挂号类别", required = true)
    @JacksonXmlProperty(localName = "C02C")
    private Integer registerType;
    /**
     * YYYY-MM-DD HH24:MI:SS
     */
    @ApiModelProperty(value = "挂号时间", required = true)
    @JacksonXmlProperty(localName = "C03")
    @JsonFormat( pattern= "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date registerTime;
    /**
     * 复诊或会诊
     */
    @ApiModelProperty(value = "诊疗类型", required = true)
    @JacksonXmlProperty(localName = "C04C")
    private Integer diagnosisType;
    /**
     * 诊疗类型为“会诊”时，此项必填
     */
    @ApiModelProperty(value = "发起会诊的医院名称")
    @JacksonXmlProperty(localName = "C05")
    private String consultationHospital;
    /**
     * 诊疗类型为“会诊”时，此项必填
     */
    @ApiModelProperty(value = "是否有专业医师陪伴")
    @JacksonXmlProperty(localName = "C06C")
    private Integer whetherNear;
    /**
     * 诊疗类型为“会诊”时，此项必填
     */
    @ApiModelProperty(value = "陪伴医师的身份证号")
    @JacksonXmlProperty(localName = "C07")
    private String nearDoctorIdCard;
    /**
     * YYYY-MM-DD HH24:MI:SS
     */
    @ApiModelProperty(value = "就诊时间", required = true)
    @JacksonXmlProperty(localName = "C08")
    @JsonFormat( pattern= "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date visitTime;

    @ApiModelProperty(value = "就诊科室编码", required = true)
    @JacksonXmlProperty(localName = "C09C")
    private String deptCode;

    @ApiModelProperty(value = "就诊科室名称", required = true)
    @JacksonXmlProperty(localName = "C09N")
    private String deptName;

    @ApiModelProperty(value = "医院内部科室代码")
    @JacksonXmlProperty(localName = "C10C")
    private String innerDeptCode;

    @ApiModelProperty(value = "医院内部科室名称")
    @JacksonXmlProperty(localName = "C10N")
    private String innerDeptName;

    @ApiModelProperty(value = "诊治医师执业证书编号", required = true)
    @JacksonXmlProperty(localName = "C11C")
    private String doctorCertificateNo;

    @ApiModelProperty(value = "诊治医师姓名", required = true)
    @JacksonXmlProperty(localName = "C11N")
    private String doctorName;

    @ApiModelProperty(value = "护士资格证书编号")
    @JacksonXmlProperty(localName = "C12C")
    private String nurseCertificateNo;

    @ApiModelProperty(value = "护士姓名")
    @JacksonXmlProperty(localName = "C12N")
    private String nurseName;
    /**
     * 药品处方必填
     */
    @ApiModelProperty(value = "审方药师身份证号码")
    @JacksonXmlProperty(localName = "C13")
    private String pharmacistIdCard;

    @ApiModelProperty(value = "既往诊断的医疗机构")
    @JacksonXmlProperty(localName = "C14")
    private String pastHospital;

    @ApiModelProperty(value = "主诉")
    @JacksonXmlProperty(localName = "C15")
    private String chiefComplaint;

    @ApiModelProperty(value = "总费用")
    @JacksonXmlProperty(localName = "C16")
    private Double amount;

    /**
     * 药品处方必填
     */
    @ApiModelProperty(value = "取药方式")
    @JacksonXmlProperty(localName = "C17C")
    private Integer dispensaryWay;

    @ApiModelProperty(value = "是否是常见病、慢性病", required = true)
    @JacksonXmlProperty(localName = "C18C")
    private Integer whetheChronicDisease;

    @ApiModelProperty(value = "是否有药师在线处方审核", required = true)
    @JacksonXmlProperty(localName = "C19C")
    private Integer whetheOnlineReview;
    /**
     * 药品处方必填
     */
    @ApiModelProperty(value = "是否有麻醉、精神类药品")
    @JacksonXmlProperty(localName = "C20C")
    private Integer narcoticDrugs;
    /**
     * 药品处方必填
     */
    @ApiModelProperty(value = "是否是儿童处方用药")
    @JacksonXmlProperty(localName = "C21C")
    private Integer childrenMedication;

    @ApiModelProperty(value = "是否互联网医院对患者进行风险提示", required = true)
    @JacksonXmlProperty(localName = "C22C")
    private Integer riskPrompt;

    @ApiModelProperty(value = "患者是否签署知情同意书", required = true)
    @JacksonXmlProperty(localName = "C23C")
    private Integer informedConsentForm;

    @ApiModelProperty(value = "患者满意度", required = true)
    @JacksonXmlProperty(localName = "C24C")
    private Integer patientSatisfaction;

    @ApiModelProperty(value = "就诊原因", required = true)
    @JacksonXmlElementWrapper(localName = "DS")
    @JacksonXmlProperty(localName = "D")
    private List<Visit> visitList;

    @ApiModelProperty(value = "中医病名信息")
    @JacksonXmlElementWrapper(localName = "GS")
    @JacksonXmlProperty(localName = "G")
    private List<Diagnose> diagnoseList;

    @ApiModelProperty(value = "中医症候信息")
    @JacksonXmlElementWrapper(localName = "HS")
    @JacksonXmlProperty(localName = "H")
    private List<Symptoms> symptomsList;

    @ApiModelProperty(value = "医嘱明细")
    @JacksonXmlElementWrapper(localName = "ES")
    @JacksonXmlProperty(localName = "E")
    private List<MedicalAdvice> medicalAdviceList;

    @ApiModelProperty(value = "费用明细")
    @JacksonXmlElementWrapper(localName = "FS")
    @JacksonXmlProperty(localName = "F")
    private List<Expense> expenseList;

}