package com.szyx.tcm.supervision.util;


import com.alibaba.fastjson2.JSONObject;
import com.fiftyonetrust.common.util.CommonConstants;
import com.fiftyonetrust.common.util.YAssert;

import com.szyx.tcm.supervision.constant.Constants;
import com.szyx.tcm.supervision.constant.HttpConstants;
import com.szyx.tcm.supervision.exception.HttpException;
import io.netty.handler.codec.http.DefaultHttpHeaders;
import io.netty.handler.codec.http.HttpHeaders;
import lombok.SneakyThrows;
import lombok.extern.slf4j.Slf4j;
import org.asynchttpclient.*;
import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;

import javax.annotation.PostConstruct;
import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * @program: tcm-parent
 * @ClassName HttpUtil
 * @description:
 * @author: jwmd
 * @create: 2023-04-25 09:41
 **/
@Slf4j
@Component
public class HttpUtil {
    @Resource
    private AsyncHttpClient httpClient;

    private static HttpUtil httpUtil;

    @PostConstruct
    public void init() {
        httpUtil = this;
        httpUtil.httpClient = this.httpClient;
    }

    /**
     * get请求
     *
     * @param url
     * @param headers 可为空
     * @param params  可为空
     * @return
     */
    @SneakyThrows
    public static String get(String url, Map<String, String> headers, Map<String, Object> params) {
        log.info("excuteGet,url:{}", url);
        log.info("excuteGet,paramMap:{}", JSONObject.toJSONString(params));
        log.info("excuteGet,headerMap:{}", JSONObject.toJSONString(headers));
        BoundRequestBuilder boundRequestBuilder = httpUtil.httpClient.prepareGet(url);
        Response response = boundRequestBuilder.setHeaders(convertHeaders(headers)).setQueryParams(convertParams(params)).execute().get();
        handleException(boundRequestBuilder.build(), response);
        String responseBody = response.getResponseBody();
        YAssert.notBlank(responseBody, "服务器返回错误");
        return responseBody;
    }

    /**
     * get请求
     *
     * @param url
     * @return
     */
    @SneakyThrows
    public static String get(String url) {
        log.info("excuteGet,url:{}", url);
        BoundRequestBuilder boundRequestBuilder = httpUtil.httpClient.prepareGet(url);
        Response response = boundRequestBuilder.execute().get();
        handleException(boundRequestBuilder.build(), response);
        String responseBody = response.getResponseBody();
        YAssert.notBlank(responseBody, "服务器返回错误");
        return responseBody;
    }

    /**
     * post json 请求
     *
     * @param url
     * @param headers 可为空
     * @param body
     * @return
     */
    @SneakyThrows
    public static String postByJson(String url, Map<String, String> headers, String body) {
        log.info("excutePost,url:{}", url);
        log.info("excutePost,body:{}", JSONObject.toJSONString(body));
        log.info("excutePost,headerMap:{}", JSONObject.toJSONString(headers));
        BoundRequestBuilder boundRequestBuilder = httpUtil.httpClient.preparePost(url);
        Response response =
                boundRequestBuilder.setHeaders(convertHeaders(headers)).addHeader(Constants.HTTP_CONTENT_TYPE, CommonConstants.CONTENT_TYPE_JSON).setBody(body)
                        .execute().get();
        handleException(boundRequestBuilder.build(), response);
        String responseBody = response.getResponseBody();
        YAssert.notBlank(responseBody, "服务器返回错误");
        return responseBody;
    }

    /**
     * post json 请求
     *
     * @param url
     * @param body
     * @return
     */
    @SneakyThrows
    public static String postByJson(String url, String body) {
        log.info("excutePost,url:{}", url);
        log.info("excutePost,body:{}", JSONObject.toJSONString(body));
        BoundRequestBuilder boundRequestBuilder = httpUtil.httpClient.preparePost(url);
        Response response = boundRequestBuilder.setBody(body).addHeader(Constants.HTTP_CONTENT_TYPE, CommonConstants.CONTENT_TYPE_JSON).execute().get();
        handleException(boundRequestBuilder.build(), response);
        String responseBody = response.getResponseBody();
        YAssert.notBlank(responseBody, "服务器返回错误");
        return responseBody;
    }

    /**
     * post json 请求
     *
     * @param url
     * @param body
     * @return
     */
    @SneakyThrows
    public static String postByJson(String url, String body, int readTimeout) {
        log.info("excutePost,url:{}", url);
        log.info("excutePost,body:{}", JSONObject.toJSONString(body));
        BoundRequestBuilder boundRequestBuilder = httpUtil.httpClient.preparePost(url);
        boundRequestBuilder.setReadTimeout(readTimeout);
        Response response = boundRequestBuilder.setBody(body).addHeader(Constants.HTTP_CONTENT_TYPE, CommonConstants.CONTENT_TYPE_JSON).execute().get();
        handleException(boundRequestBuilder.build(), response);
        String responseBody = response.getResponseBody();
        YAssert.notBlank(responseBody, "服务器返回错误");
        return responseBody;
    }


    /**
     * post json 请求
     *
     * @param url
     * @param body
     * @return
     */
    @SneakyThrows
    public static String postByXMl(String url, String body) {
        log.info("excutePost,url:{}", url);
        log.info("excutePost,body:{}", JSONObject.toJSONString(body));
        BoundRequestBuilder boundRequestBuilder = httpUtil.httpClient.preparePost(url);
        Response response = boundRequestBuilder.setBody(body).addHeader(Constants.HTTP_CONTENT_TYPE, "application/xml").execute().get();
        handleException(boundRequestBuilder.build(), response);
        String responseBody = response.getResponseBody();
        YAssert.notBlank(responseBody, "服务器返回错误");
        return responseBody;
    }

    /**
     * post form表单请求
     *
     * @param url
     * @param headers 可为空
     * @param params
     * @return
     */
    @SneakyThrows
    public static String postByForm(String url, Map<String, String> headers, Map<String, Object> params) {
        log.info("excutePost,url:{}", url);
        log.info("excutePost,paramMap:{}", JSONObject.toJSONString(params));
        log.info("excutePost,headerMap:{}", JSONObject.toJSONString(headers));
        BoundRequestBuilder boundRequestBuilder = httpUtil.httpClient.preparePost(url);
        Response response = boundRequestBuilder.setHeaders(convertHeaders(headers)).setFormParams(convertParams(params)).execute().get();
        handleException(boundRequestBuilder.build(), response);
        String responseBody = response.getResponseBody();
        YAssert.notBlank(responseBody, "服务器返回错误");
        return responseBody;
    }

    /**
     * post form表单请求
     *
     * @param url
     * @param params
     * @return
     */
    @SneakyThrows
    public static String postByForm(String url, Map<String, Object> params) {
        log.info("excutePost,url:{}", url);
        log.info("excutePost,paramMap:{}", JSONObject.toJSONString(params));
        BoundRequestBuilder boundRequestBuilder = httpUtil.httpClient.preparePost(url);
        Response response = boundRequestBuilder.setFormParams(convertParams(params)).execute().get();
        handleException(boundRequestBuilder.build(), response);
        String responseBody = response.getResponseBody();
        YAssert.notBlank(responseBody, "服务器返回错误");
        return responseBody;
    }

    /**
     * 根据map转换为header
     *
     * @param map
     * @return
     */
    public static HttpHeaders convertHeaders(Map<String, String> map) {
        if (CollectionUtils.isEmpty(map)) {
            return null;
        }
        HttpHeaders headers = new DefaultHttpHeaders();
        for (Map.Entry<String, String> entrySet : map.entrySet()) {
            headers.add(entrySet.getKey(), entrySet.getValue());
        }
        return headers;
    }

    /**
     * 根据map转换为params
     *
     * @param params
     * @return
     */
    public static List<Param> convertParams(Map<String, Object> params) {
        if (CollectionUtils.isEmpty(params)) {
            return new ArrayList<>();
        }
        List<Param> paramList = new ArrayList<Param>(params.size());

        for (Map.Entry<String, Object> entrySet : params.entrySet()) {
            if (entrySet.getValue() instanceof List) {
                for (Object o : (List) entrySet.getValue()) {
                    paramList.add(new Param(entrySet.getKey(), String.valueOf(o)));
                }


            } else {
                paramList.add(new Param(entrySet.getKey(), String.valueOf(entrySet.getValue())));
            }

        }
        return paramList;
    }

    /**
     * 统一处理返回异常
     *
     * @param response
     */
    private static void handleException(Request request, Response response) {
        log.info("response响应为:{}", response.getResponseBody());
        if (response.getStatusCode() >= HttpConstants.StatusCode.CLIENT_ERROR) {
            HttpException currException = HttpException.mapException(response.getStatusCode(), response.getResponseBody());
            log.error("HttpException occurred Uri: {} HttpException: {}", request.getUrl(), currException.toString());
            throw currException;
        }
    }

}